==> ktp-desktop-applets-0.7.0.tar.bz2: ktp-desktop-applets-0.7.0/presence/plasma-applet-ktp-presence.desktop.cmake <==
[Desktop Entry]
Name=Instant Messaging Presence
Name[bs]=Prisutnost za instant poruke
Name[ca]=Presència de missatgeria instantània
Name[ca@valencia]=Presència de missatgeria instantània
Name[cs]=Widget stavu komunikátoru
Name[da]=Instant messaging-tilstedeværelse
Name[de]=Instant-Messenger-Anwesenheit
Name[el]=Παρουσία με στιγμιαίο μήνυμα
Name[es]=Presencia de mensajería instantánea
Name[et]=Kiirsuhtluse olek
Name[fi]=Pikaviestinnän läsnäolo
Name[fr]=Présence pour votre messagerie instantanée
Name[gl]=Presenza da mensaxería instantánea
Name[hu]=Azonnali üzenetküldési állapot
Name[ia]=Presentia de Messageria instantanee
Name[it]=Presenza di messaggistica istantanea
Name[kk]=Лезде хабарласу бар ма
Name[lt]=TP matomumas
Name[mr]=त्वरित संदेश उपस्थिती
Name[nb]=Tilstede for lynmeldingssystemet
Name[nl]=Aanwezigheid van Instant Messaging
Name[pl]=Obecność w komunikatorze internetowym
Name[pt]=Presença nas Mensagens Instantâneas
Name[pt_BR]=Presença nas mensagens instantâneas
Name[ro]=Prezență în mesageria instantanee
Name[ru]=Диспетчер обмена сообщениями
Name[sk]=Prítomnosť instant messagingu
Name[sl]=Prisotnost hipnega sporočanja
Name[sr]=Брзогласничко присуство
Name[sr@ijekavian]=Брзогласничко присуство
Name[sr@ijekavianlatin]=Brzoglasničko prisustvo
Name[sr@latin]=Brzoglasničko prisustvo
Name[sv]=Direktmeddelande finns
Name[tr]=Anında Mesajlaşma Varlığı
Name[uk]=Присутність у обміні повідомленнями
Name[x-test]=xxInstant Messaging Presencexx
Name[zh_CN]=即时通讯状态
Name[zh_TW]=即時訊息呈現
Type=Service
ServiceTypes=Plasma/Applet
Icon=user-online

X-Plasma-DefaultSize=128,128

X-KDE-Library=plasma_applet_ktp_presence
X-KDE-PluginInfo-Name=org.kde.ktp-presence
X-KDE-PluginInfo-Category=Online Services
X-KDE-PluginInfo-Author=Francesco Nwokeka
X-KDE-PluginInfo-Email=francesco.nwokeka@gmail.com
X-KDE-PluginInfo-Version=@KTP_DESKTOP_APPLETS_VERSION@
X-KDE-PluginInfo-Website=http://telepathy.freedesktop.org/
X-KDE-PluginInfo-Depends=
X-KDE-PluginInfo-License=LGPL
X-KDE-PluginInfo-EnabledByDefault=true

X-Plasma-NotificationArea=true

==> ktp-desktop-applets-0.7.1.tar.bz2: ktp-desktop-applets-0.7.1/presence/plasma-applet-ktp-presence.desktop.cmake <==
[Desktop Entry]
Name=Instant Messaging Presence
Name[bs]=Prisutnost za instant poruke
Name[ca]=Presència de missatgeria instantània
Name[ca@valencia]=Presència de missatgeria instantània
Name[cs]=Widget stavu komunikátoru
Name[da]=Instant messaging-tilstedeværelse
Name[de]=Instant-Messenger-Anwesenheit
Name[el]=Παρουσία με στιγμιαίο μήνυμα
Name[es]=Presencia de mensajería instantánea
Name[et]=Kiirsuhtluse olek
Name[fi]=Pikaviestinnän läsnäolo
Name[fr]=Présence de la messagerie instantanée
Name[gl]=Presenza da mensaxería instantánea
Name[hu]=Azonnali üzenetküldési állapot
Name[ia]=Presentia de Messageria instantanee
Name[it]=Presenza di messaggistica istantanea
Name[kk]=Лезде хабарласу бар ма
Name[lt]=TP matomumas
Name[mr]=त्वरित संदेश उपस्थिती
Name[nb]=Tilstede for lynmeldingssystemet
Name[nl]=Aanwezigheid van Instant Messaging
Name[pl]=Obecność w komunikatorze internetowym
Name[pt]=Presença nas Mensagens Instantâneas
Name[pt_BR]=Presença nas mensagens instantâneas
Name[ro]=Prezență în mesageria instantanee
Name[ru]=Диспетчер обмена сообщениями
Name[sk]=Prítomnosť instant messagingu
Name[sl]=Prisotnost hipnega sporočanja
Name[sr]=Брзогласничко присуство
Name[sr@ijekavian]=Брзогласничко присуство
Name[sr@ijekavianlatin]=Brzoglasničko prisustvo
Name[sr@latin]=Brzoglasničko prisustvo
Name[sv]=Direktmeddelande finns
Name[tr]=Anında Mesajlaşma Varlığı
Name[uk]=Присутність у обміні повідомленнями
Name[x-test]=xxInstant Messaging Presencexx
Name[zh_CN]=即时通讯状态
Name[zh_TW]=即時訊息呈現
Type=Service
ServiceTypes=Plasma/Applet
Icon=user-online

X-Plasma-DefaultSize=128,128

X-KDE-Library=plasma_applet_ktp_presence
X-KDE-PluginInfo-Name=org.kde.ktp-presence
X-KDE-PluginInfo-Category=Online Services
X-KDE-PluginInfo-Author=Francesco Nwokeka
X-KDE-PluginInfo-Email=francesco.nwokeka@gmail.com
X-KDE-PluginInfo-Version=@KTP_DESKTOP_APPLETS_VERSION@
X-KDE-PluginInfo-Website=http://telepathy.freedesktop.org/
X-KDE-PluginInfo-Depends=
X-KDE-PluginInfo-License=LGPL
X-KDE-PluginInfo-EnabledByDefault=true

X-Plasma-NotificationArea=true
